/* $Id: gtk-gui.cc,v 1.10 2002/02/13 00:36:16 richard Exp $ -*- C++ -*-
  __   _
  |_) /|  Copyright (C) 2001-2002 Richard Atterer
  | \/|  <richard@atterer.net>
   '` 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2 or
  later. See the file COPYING for details.

  Interface to GTK GUI. Sets up global variables pointing to the main
  GUI elements.

  "Glue code" between the interface as generated by glade (in
  gtk-interface.*, gtk-support.*) and jigdo's functionality.

*/

#include <gtk-gui.hh>
#include <joblist.hh>
//______________________________________________________________________

GUI::Window GUI::window;
GUI::Filesel GUI::filesel;
GUI::Errorbox GUI::errorbox;
//______________________________________________________________________

// File selection dialogue - helper functions
namespace {
  using namespace GUI;

  GtkEntry* filesel_state = 0;

  // Private function for filesel_open below
  void on_filesel_okButton(GtkWidget*, gpointer) {
    if (filesel_state != 0) {
      // Copy over filename to the right GtkEntry
      GtkFileSelection* fileselObj = GTK_FILE_SELECTION(filesel.filesel);
      gtk_entry_set_text(filesel_state,
                         gtk_file_selection_get_filename(fileselObj));
    }
    gtk_widget_hide(filesel.filesel); // Close file selection window
  }

  /* Called to open filesel on e.g. a button click. When filesel's OK
     button is clicked, the selected filename is copied to "entry". */
  void filesel_open(GtkWidget*, gpointer entry) {
    gtk_widget_show(filesel.filesel);
    filesel_state = GTK_ENTRY(entry);
  }
}
//______________________________________________________________________

/* Initialisation of the GUI. Mostly does some post-processing of the
   glade-generated data structures, connecting button press events to
   the corresponding function etc. */
void GUI::create() {
  window.create();
  filesel.create();
  errorbox.create();
  JobVector::initAfterGtk();

  /* Remove tabs from main window notebook, since the user is only
     allowed to switch between the pages using clicks on buttons/list
     entries. */
  gtk_notebook_set_show_tabs(GTK_NOTEBOOK(window.invisibleNotebook),FALSE);

  // Set background white for jigdo welcome screen
  GtkStyle* blackWhiteStyle =
    gtk_style_copy(gtk_widget_get_style(window.aboutJigdoLabel));
  GdkColormap* colMap = gdk_colormap_get_system();
  gdk_color_white(colMap, &(blackWhiteStyle->bg[GTK_STATE_NORMAL]));
  gdk_color_black(colMap, &(blackWhiteStyle->fg[GTK_STATE_NORMAL]));
  gtk_widget_set_style(window.aboutBgnd, blackWhiteStyle);
  gtk_widget_set_style(window.aboutJigdoLabel, blackWhiteStyle);
  gtk_style_unref(blackWhiteStyle);

  // Grey out unimplemented stuff
  gtk_widget_set_sensitive(window.toolbarReuse, FALSE);
  gtk_widget_set_sensitive(window.toolbarServers, FALSE);
  gtk_widget_set_sensitive(window.toolbarPause, FALSE);
  gtk_widget_set_sensitive(window.toolbarAbort, FALSE);
  gtk_widget_set_sensitive(window.toolbarSettings, FALSE);

  /* Handler to copy filename to right GtkEntry when OK is pressed
     in filesel */
  gtk_signal_connect(GTK_OBJECT(filesel.okButton), "clicked",
                     GTK_SIGNAL_FUNC(on_filesel_okButton), NULL);

  /* Open filesel window when buttons are clicked, enter result in
     appropriate GtkEntry */
  gtk_signal_connect(GTK_OBJECT(window.open_URLSel), "clicked",
                     GTK_SIGNAL_FUNC(filesel_open),
                     GTK_OBJECT(window.open_URL));
  gtk_signal_connect(GTK_OBJECT(window.open_DestSel), "clicked",
                     GTK_SIGNAL_FUNC(filesel_open),
                     GTK_OBJECT(window.open_Dest));

  gtk_entry_set_text(GTK_ENTRY(window.open_Dest), g_get_home_dir());
# if DEBUG
  gtk_entry_set_text(GTK_ENTRY(window.open_URL),
                     "http://127.0.0.1/~richard/ironmaiden/image");
# endif
}
//______________________________________________________________________

// Callback handlers

void on_toolbarExit_clicked(GtkButton*, gpointer) {
  gtk_main_quit();
}

gboolean on_window_delete_event(GtkWidget*, GdkEvent*, gpointer) {
  gtk_main_quit();
  return FALSE;
}

void setNotebookPage(GtkWidget* pageObject) {
  GtkNotebook* n = GTK_NOTEBOOK(pageObject->parent);
  gtk_notebook_set_page(n, gtk_notebook_page_num(n, pageObject));
}

void on_openButton_clicked(GtkButton*, gpointer) {
  Job* j = new DownloadJob(gtk_entry_get_text(GTK_ENTRY(window.open_URL)),
                           gtk_entry_get_text(GTK_ENTRY(window.open_Dest)));
  GUI::jobVector.append(j);
}
